@@ -38,19 +38,23 @@ def create_db_connection(path: str):
     return connection
 
 
-def execute_db_query(connection, query: str) -> None:
+def execute_db_query(connection, query: str, values: tuple = None) -> None:
     """Executes a SQL query on the Sqlite3 database
 
     Args:
         connection: A database connection object
         query: The SQL query as a string
+        values: A tuple of values to be inserted into the query
 
     Returns:
         Nothing.
     """
     cursor = connection.cursor()
     try:
-        cursor.execute(query)
+        if values:
+            cursor.execute(query, values)
+        else:
+            cursor.execute(query)
         connection.commit()
     except sqlite3.Error as e:
         print(f"The error '{e}' occurred")
@@ -66,42 +70,29 @@ def save_game_to_db(connection, pgn: dict) -> None:
     Returns:
         Nothing.
     """
+
     execute_db_query(
         connection,
-        f"""INSERT INTO
-        games (
-            event,
-            site,
-            date,
-            round,
-            white,
-            black,
-            result,
-            eco,
-            white_elo,
-            black_elo,
-            variant,
-            time_control,
-            termination,
-            moves)
-        VALUES
+        """INSERT INTO
+        games(event, site, date, round, white, black, result, eco, white_elo,
+        black_elo, variant, time_control, termination, moves) 
+        VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);""",
         (
-            '{pgn["event"]}',
-            '{pgn["site"]}',
-            '{pgn["date"]}',
-            '{pgn["round"]}',
-            '{pgn["white"]}',
-            '{pgn["black"]}',
-            '{pgn["result"]}',
-            '{pgn["eco"]}',
-            '{pgn["white_elo"]}',
-            '{pgn["black_elo"]}',
-            '{pgn["variant"]}',
-            '{pgn["time_control"]}',
-            '{pgn["termination"]}',
-            '{pgn["moves"]}'
-        );
-        """,
+            pgn["event"],
+            pgn["site"],
+            pgn["date"],
+            pgn["round"],
+            pgn["white"],
+            pgn["black"],
+            pgn["result"],
+            pgn["eco"],
+            pgn["white_elo"],
+            pgn["black_elo"],
+            pgn["variant"],
+            pgn["time_control"],
+            pgn["termination"],
+            pgn["moves"],
+        ),
     )
 
 
@@ -114,7 +105,13 @@ def fetch_chess_dotcom_games(user: str) -> list:
     Returns:
         list: A list of all games for that user.
     """
-    req = requests.get(f"https://api.chess.com/pub/player/{user}/games/archives")
+    # The chess.com API requires a user agent header to be set with an email address.
+    # See here for the details:
+    # https://www.chess.com/announcements/view/breaking-change-user-agent-contact-info-required
+    req = requests.get(
+        f"https://api.chess.com/pub/player/{user}/games/archives",
+        headers={"User-Agent": "test@gmail.com"},
+    )
     archive_urls = req.json()["archives"]
     games_list = []
 
@@ -164,7 +161,6 @@ def build_pgn_dict(pgn: str) -> dict:
 
     for line in pgn_lines:
         if line.startswith("["):
-
             key_pattern = re.compile(r"([^\s]+)")
             value_pattern = re.compile(r"\"(.+?)\"")
 
