@@ -1,6 +1,7 @@
 import requests
 from click.testing import CliRunner
-from pgn_to_sqlite.cli import build_pgn_dict, convert_to_snake_case, cli
+
+from pgn_to_sqlite.cli import build_pgn_dict, cli, convert_to_snake_case
 
 
 def test_snake_case_conversion():
@@ -27,7 +28,10 @@ def test_build_png_dict_from_lichess():
 
 
 def test_chess_dotcom_api_endpoint():
-    r = requests.get("https://api.chess.com/pub/player/endlesstrax/games/archives")
+    r = requests.get(
+        "https://api.chess.com/pub/player/endlesstrax/games/archives",
+        headers={"User-Agent": "test@gmail.com"},
+    )
     assert r.status_code == 200
 
 
